/*********************************************************************
*                    SEGGER Microcontroller GmbH                     *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2020  SEGGER Microcontroller GmbH                *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V6.14 - Graphical user interface for embedded applications **
emWin is protected by international copyright laws.   Knowledge of the
source code may not be used to write a similar product.  This file may
only  be used  in accordance  with  a license  and should  not be  re-
distributed in any way. We appreciate your understanding and fairness.
----------------------------------------------------------------------
File        : GUI_DrawGIFAsBitmap.c
Purpose     : This sample demonstrates a method of displaying GIF
              animations, that can often improve performance.
              Instead of the GIF file, each sub-image is saved as a
              C bitmap and they are drawn using timers and an index.
Requirements: WindowManager - (x)
              MemoryDevices - ( )
              AntiAliasing  - ( )
              VNC-Server    - ( )
              PNG-Library   - ( )
              TrueTypeFonts - ( )
---------------------------END-OF-HEADER------------------------------
*/

#include "DIALOG.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define MS_PER_FRAME 60

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
/*********************************************************************
*
*       _acThrobber_0_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_0_50x50[] = {
  /* RLE: 023 Pixels @ 00,00 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,00 */ 4, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 044 Pixels @ 27,00 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,01 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 041 Pixels @ 29,01 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,02 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,03 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 038 Pixels @ 31,03 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,06 */ 6, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 15,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 31,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,06 */ 6, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 016 Pixels @ 41,06 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,07 */ 9, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,07 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 014 Pixels @ 43,07 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,09 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 18,09 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 18,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,10 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 29,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,11 */ 6, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 28,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 014 Pixels @ 18,12 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 017 Pixels @ 17,15 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,15 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 018 Pixels @ 42,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,17 */ 4, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 022 Pixels @ 14,17 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,17 */ 4, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 064 Pixels @ 40,17 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,19 */ 5, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 032 Pixels @ 09,19 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,19 */ 5, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 006 Pixels @ 46,19 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,20 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 48,20 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,21 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 001 Pixels @ 49,22 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 00,23 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,28 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 028 Pixels @ 11,28 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,29 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 030 Pixels @ 10,29 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,29 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 006 Pixels @ 48,29 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,30 */ 5, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,30 */ 5, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 064 Pixels @ 46,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,32 */ 4, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 022 Pixels @ 14,32 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,32 */ 4, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,33 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 018 Pixels @ 16,33 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,33 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,34 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 017 Pixels @ 17,34 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 013 Pixels @ 43,34 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,35 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 014 Pixels @ 18,36 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,36 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,41 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 014 Pixels @ 43,41 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 016 Pixels @ 43,42 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,43 */ 6, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,43 */ 6, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 028 Pixels @ 41,43 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 038 Pixels @ 31,44 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,49 */ 4, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 023 Pixels @ 27,49 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 983 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_0_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_0_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _acThrobber_1_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_1_50x50[] = {
  /* RLE: 023 Pixels @ 00,00 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,00 */ 4, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 044 Pixels @ 27,00 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,01 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 041 Pixels @ 29,01 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,02 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,03 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 038 Pixels @ 31,03 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,06 */ 6, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 15,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 31,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,06 */ 6, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 016 Pixels @ 41,06 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,07 */ 9, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,07 */ 9, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 014 Pixels @ 43,07 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,09 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 18,09 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 18,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,10 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 29,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,11 */ 6, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 28,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 014 Pixels @ 18,12 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 017 Pixels @ 17,15 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,15 */ 9, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 018 Pixels @ 42,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,17 */ 4, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 022 Pixels @ 14,17 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,17 */ 4, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 064 Pixels @ 40,17 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,19 */ 5, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 032 Pixels @ 09,19 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,19 */ 5, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 006 Pixels @ 46,19 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,20 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 48,20 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,21 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 001 Pixels @ 49,22 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 00,23 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,28 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 028 Pixels @ 11,28 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,29 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 030 Pixels @ 10,29 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,29 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 006 Pixels @ 48,29 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,30 */ 5, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,30 */ 5, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 064 Pixels @ 46,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,32 */ 4, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 022 Pixels @ 14,32 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,32 */ 4, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,33 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 018 Pixels @ 16,33 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,33 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,34 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 017 Pixels @ 17,34 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 013 Pixels @ 43,34 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,35 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 014 Pixels @ 18,36 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,36 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,41 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 014 Pixels @ 43,41 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 016 Pixels @ 43,42 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,43 */ 6, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,43 */ 6, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 028 Pixels @ 41,43 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 038 Pixels @ 31,44 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,49 */ 4, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 023 Pixels @ 27,49 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 983 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_1_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_1_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _acThrobber_2_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_2_50x50[] = {
  /* RLE: 023 Pixels @ 00,00 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,00 */ 4, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 044 Pixels @ 27,00 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,01 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 041 Pixels @ 29,01 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,02 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,03 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 038 Pixels @ 31,03 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,06 */ 6, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 15,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 31,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,06 */ 6, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 016 Pixels @ 41,06 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,07 */ 9, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,07 */ 9, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 014 Pixels @ 43,07 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,09 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 18,09 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 18,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,10 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 29,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,11 */ 6, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 28,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 014 Pixels @ 18,12 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 017 Pixels @ 17,15 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,15 */ 9, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 018 Pixels @ 42,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,17 */ 4, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 022 Pixels @ 14,17 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,17 */ 4, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 064 Pixels @ 40,17 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,19 */ 5, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 032 Pixels @ 09,19 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,19 */ 5, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 006 Pixels @ 46,19 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,20 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 48,20 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,21 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 001 Pixels @ 49,22 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 00,23 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,28 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 028 Pixels @ 11,28 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,29 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 030 Pixels @ 10,29 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,29 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 006 Pixels @ 48,29 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,30 */ 5, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,30 */ 5, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 064 Pixels @ 46,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,32 */ 4, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 022 Pixels @ 14,32 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,32 */ 4, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,33 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 018 Pixels @ 16,33 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,33 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,34 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 017 Pixels @ 17,34 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 013 Pixels @ 43,34 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,35 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 014 Pixels @ 18,36 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,36 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,41 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 014 Pixels @ 43,41 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 016 Pixels @ 43,42 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,43 */ 6, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,43 */ 6, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 028 Pixels @ 41,43 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 038 Pixels @ 31,44 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,49 */ 4, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 023 Pixels @ 27,49 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 983 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_2_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_2_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _acThrobber_3_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_3_50x50[] = {
  /* RLE: 023 Pixels @ 00,00 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,00 */ 4, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 044 Pixels @ 27,00 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,01 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 041 Pixels @ 29,01 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,02 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,03 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 038 Pixels @ 31,03 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,06 */ 6, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 15,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 31,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,06 */ 6, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 016 Pixels @ 41,06 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,07 */ 9, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,07 */ 9, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 014 Pixels @ 43,07 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,09 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 18,09 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 18,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,10 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 29,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,11 */ 6, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 28,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 014 Pixels @ 18,12 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 017 Pixels @ 17,15 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,15 */ 9, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 018 Pixels @ 42,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,17 */ 4, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 022 Pixels @ 14,17 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,17 */ 4, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 064 Pixels @ 40,17 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,19 */ 5, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 032 Pixels @ 09,19 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,19 */ 5, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 006 Pixels @ 46,19 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,20 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 48,20 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,21 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 001 Pixels @ 49,22 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 00,23 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,28 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 028 Pixels @ 11,28 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,29 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 030 Pixels @ 10,29 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,29 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 006 Pixels @ 48,29 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,30 */ 5, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,30 */ 5, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 064 Pixels @ 46,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,32 */ 4, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 022 Pixels @ 14,32 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,32 */ 4, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,33 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 018 Pixels @ 16,33 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,33 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,34 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 017 Pixels @ 17,34 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 013 Pixels @ 43,34 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,35 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 014 Pixels @ 18,36 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,36 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,41 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 014 Pixels @ 43,41 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 016 Pixels @ 43,42 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,43 */ 6, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,43 */ 6, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 028 Pixels @ 41,43 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 038 Pixels @ 31,44 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,49 */ 4, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 023 Pixels @ 27,49 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 983 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_3_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_3_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _acThrobber_4_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_4_50x50[] = {
  /* RLE: 023 Pixels @ 00,00 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,00 */ 4, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 044 Pixels @ 27,00 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,01 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 041 Pixels @ 29,01 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,02 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,03 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 038 Pixels @ 31,03 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,06 */ 6, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 004 Pixels @ 15,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 31,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,06 */ 6, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 016 Pixels @ 41,06 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,07 */ 9, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,07 */ 9, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 014 Pixels @ 43,07 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,09 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 18,09 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 18,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,10 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 29,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,11 */ 6, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 004 Pixels @ 28,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 014 Pixels @ 18,12 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 017 Pixels @ 17,15 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,15 */ 9, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 018 Pixels @ 42,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,17 */ 4, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 022 Pixels @ 14,17 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,17 */ 4, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 064 Pixels @ 40,17 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,19 */ 5, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 032 Pixels @ 09,19 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,19 */ 5, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 006 Pixels @ 46,19 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,20 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 48,20 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,21 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 001 Pixels @ 49,22 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 00,23 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,28 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 028 Pixels @ 11,28 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,29 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 030 Pixels @ 10,29 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,29 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 006 Pixels @ 48,29 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,30 */ 5, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,30 */ 5, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 064 Pixels @ 46,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,32 */ 4, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 022 Pixels @ 14,32 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,32 */ 4, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,33 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 018 Pixels @ 16,33 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,33 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,34 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 017 Pixels @ 17,34 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 013 Pixels @ 43,34 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,35 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 014 Pixels @ 18,36 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,36 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,41 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 014 Pixels @ 43,41 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 016 Pixels @ 43,42 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,43 */ 6, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,43 */ 6, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 028 Pixels @ 41,43 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 038 Pixels @ 31,44 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,49 */ 4, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 023 Pixels @ 27,49 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 983 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_4_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_4_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _acThrobber_5_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_5_50x50[] = {
  /* RLE: 024 Pixels @ 00,00 */ 24, 0x00, 0x00, 0x00, 0xFF, 
  /* ABS: 002 Pixels @ 24,00 */ 0, 2, 0x44, 0x44, 0x48, 0x00, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 046 Pixels @ 26,00 */ 46, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 007 Pixels @ 22,01 */ 7, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 042 Pixels @ 29,01 */ 42, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 21,02 */ 9, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,03 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 039 Pixels @ 30,03 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 09,06 */ 5, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 005 Pixels @ 14,06 */ 5, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 005 Pixels @ 31,06 */ 5, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 36,06 */ 5, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 017 Pixels @ 41,06 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,07 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,07 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 015 Pixels @ 42,07 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,09 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 17,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 18,10 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,10 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 30,10 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 007 Pixels @ 22,11 */ 7, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 29,11 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 006 Pixels @ 18,12 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* ABS: 002 Pixels @ 24,12 */ 0, 2, 0x44, 0x44, 0x48, 0x00, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 006 Pixels @ 26,12 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 016 Pixels @ 17,15 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,15 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 017 Pixels @ 42,16 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,17 */ 6, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 021 Pixels @ 15,17 */ 21, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 36,17 */ 5, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 063 Pixels @ 41,17 */ 63, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 04,19 */ 4, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 034 Pixels @ 08,19 */ 34, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 42,19 */ 4, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 007 Pixels @ 46,19 */ 7, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 007 Pixels @ 03,20 */ 7, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 48,20 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 02,21 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 49,22 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,23 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,28 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 027 Pixels @ 12,28 */ 27, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 02,29 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 028 Pixels @ 11,29 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 39,29 */ 9, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 005 Pixels @ 48,29 */ 5, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 03,30 */ 6, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 41,30 */ 6, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 064 Pixels @ 47,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* ABS: 002 Pixels @ 11,32 */ 0, 2, 0x72, 0x72, 0x76, 0x00, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 024 Pixels @ 13,32 */ 24, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 003 Pixels @ 37,32 */ 3, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 007 Pixels @ 08,33 */ 7, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 020 Pixels @ 15,33 */ 20, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 007 Pixels @ 35,33 */ 7, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,34 */ 9, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 018 Pixels @ 16,34 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 014 Pixels @ 43,34 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,35 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 015 Pixels @ 18,36 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,36 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,41 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 013 Pixels @ 44,41 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 015 Pixels @ 43,42 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 007 Pixels @ 08,43 */ 7, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 007 Pixels @ 35,43 */ 7, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 019 Pixels @ 42,43 */ 19, 0x00, 0x00, 0x00, 0xFF, 
  /* ABS: 002 Pixels @ 11,44 */ 0, 2, 0x72, 0x72, 0x76, 0x00, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 006 Pixels @ 13,44 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 006 Pixels @ 31,44 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* ABS: 002 Pixels @ 37,44 */ 0, 2, 0x91, 0x91, 0x94, 0x00, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 030 Pixels @ 39,44 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 23,49 */ 5, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 022 Pixels @ 28,49 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 1041 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_5_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_5_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _acThrobber_6_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_6_50x50[] = {
  /* RLE: 023 Pixels @ 00,00 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,00 */ 4, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 044 Pixels @ 27,00 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,01 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 041 Pixels @ 29,01 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,02 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,03 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 038 Pixels @ 31,03 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,06 */ 6, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 15,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 004 Pixels @ 31,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,06 */ 6, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 016 Pixels @ 41,06 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,07 */ 9, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,07 */ 9, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 014 Pixels @ 43,07 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,09 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 18,09 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 18,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,10 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 003 Pixels @ 29,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,11 */ 6, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 004 Pixels @ 28,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 014 Pixels @ 18,12 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 017 Pixels @ 17,15 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,15 */ 9, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 018 Pixels @ 42,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,17 */ 4, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 022 Pixels @ 14,17 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,17 */ 4, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 064 Pixels @ 40,17 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,19 */ 5, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 032 Pixels @ 09,19 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,19 */ 5, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 006 Pixels @ 46,19 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,20 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 48,20 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,21 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 001 Pixels @ 49,22 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 00,23 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,28 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 028 Pixels @ 11,28 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,29 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 030 Pixels @ 10,29 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,29 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 006 Pixels @ 48,29 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,30 */ 5, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,30 */ 5, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 064 Pixels @ 46,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,32 */ 4, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 022 Pixels @ 14,32 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,32 */ 4, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,33 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 018 Pixels @ 16,33 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,33 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,34 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 017 Pixels @ 17,34 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 013 Pixels @ 43,34 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,35 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 014 Pixels @ 18,36 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,36 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,41 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 014 Pixels @ 43,41 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 016 Pixels @ 43,42 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,43 */ 6, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,43 */ 6, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 028 Pixels @ 41,43 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 038 Pixels @ 31,44 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,49 */ 4, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 023 Pixels @ 27,49 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 983 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_6_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_6_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _acThrobber_7_50x50
*/
static GUI_CONST_STORAGE unsigned char _acThrobber_7_50x50[] = {
  /* RLE: 023 Pixels @ 00,00 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,00 */ 4, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 044 Pixels @ 27,00 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,01 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 041 Pixels @ 29,01 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,02 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 040 Pixels @ 30,02 */ 40, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,03 */ 11, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 038 Pixels @ 31,03 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,04 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 038 Pixels @ 31,04 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,05 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 028 Pixels @ 31,05 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,06 */ 6, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 15,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,06 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 31,06 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,06 */ 6, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 016 Pixels @ 41,06 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,07 */ 9, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 16,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,07 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 31,07 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,07 */ 9, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 014 Pixels @ 43,07 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,08 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 17,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,08 */ 12, 0x63, 0x63, 0x66, 0x00, 
  /* ABS: 002 Pixels @ 31,08 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,08 */ 10, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 013 Pixels @ 43,08 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,09 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* ABS: 002 Pixels @ 18,09 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,09 */ 10, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 30,09 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,09 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,09 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,10 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 003 Pixels @ 18,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,10 */ 8, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 003 Pixels @ 29,10 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,10 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,10 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,11 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 004 Pixels @ 18,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,11 */ 6, 0x63, 0x63, 0x66, 0x00, 
  /* RLE: 004 Pixels @ 28,11 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,11 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,11 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,12 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 014 Pixels @ 18,12 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,12 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,12 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,13 */ 12, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 014 Pixels @ 18,13 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,13 */ 12, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 012 Pixels @ 44,13 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,14 */ 11, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 016 Pixels @ 17,14 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,14 */ 11, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 013 Pixels @ 44,14 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,15 */ 10, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 017 Pixels @ 17,15 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,15 */ 9, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 015 Pixels @ 43,15 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,16 */ 8, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 018 Pixels @ 16,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,16 */ 8, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 018 Pixels @ 42,16 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,17 */ 4, 0x72, 0x72, 0x76, 0x00, 
  /* RLE: 022 Pixels @ 14,17 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,17 */ 4, 0x54, 0x54, 0x57, 0x00, 
  /* RLE: 064 Pixels @ 40,17 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,19 */ 5, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 032 Pixels @ 09,19 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,19 */ 5, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 006 Pixels @ 46,19 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,20 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 030 Pixels @ 10,20 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,20 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 48,20 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,21 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 028 Pixels @ 11,21 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,21 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 49,21 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,22 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 026 Pixels @ 12,22 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,22 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 001 Pixels @ 49,22 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 00,23 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 026 Pixels @ 12,23 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,23 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 00,24 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 026 Pixels @ 12,24 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,24 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 00,25 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 026 Pixels @ 12,25 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,25 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 012 Pixels @ 00,26 */ 12, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 026 Pixels @ 12,26 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 38,26 */ 12, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 001 Pixels @ 00,27 */ 1, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 01,27 */ 11, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 026 Pixels @ 12,27 */ 26, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 38,27 */ 11, 0x44, 0x44, 0x48, 0x00, 
  /* ABS: 002 Pixels @ 49,27 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 01,28 */ 10, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 028 Pixels @ 11,28 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 39,28 */ 10, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 003 Pixels @ 49,28 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 02,29 */ 8, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 030 Pixels @ 10,29 */ 30, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 40,29 */ 8, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 006 Pixels @ 48,29 */ 6, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 04,30 */ 5, 0x81, 0x81, 0x85, 0x00, 
  /* RLE: 032 Pixels @ 09,30 */ 32, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 005 Pixels @ 41,30 */ 5, 0x44, 0x44, 0x48, 0x00, 
  /* RLE: 064 Pixels @ 46,30 */ 64, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 10,32 */ 4, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 022 Pixels @ 14,32 */ 22, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 36,32 */ 4, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 018 Pixels @ 40,32 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 08,33 */ 8, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 018 Pixels @ 16,33 */ 18, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 34,33 */ 8, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 015 Pixels @ 42,33 */ 15, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,34 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 017 Pixels @ 17,34 */ 17, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,34 */ 9, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 013 Pixels @ 43,34 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 06,35 */ 11, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 016 Pixels @ 17,35 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,35 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,35 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,36 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 014 Pixels @ 18,36 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,36 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,36 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,37 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 014 Pixels @ 18,37 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,37 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,37 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,38 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 18,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 22,38 */ 6, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 28,38 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,38 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,38 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,39 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 18,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,39 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 29,39 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 32,39 */ 12, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 012 Pixels @ 44,39 */ 12, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 06,40 */ 12, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 18,40 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,40 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 30,40 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 33,40 */ 11, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 013 Pixels @ 44,40 */ 13, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 07,41 */ 10, 0x91, 0x91, 0x94, 0x00, 
  /* ABS: 002 Pixels @ 17,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,41 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* ABS: 002 Pixels @ 31,41 */ 0, 2, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 33,41 */ 10, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 014 Pixels @ 43,41 */ 14, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 07,42 */ 9, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 003 Pixels @ 16,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,42 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 003 Pixels @ 31,42 */ 3, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 009 Pixels @ 34,42 */ 9, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 016 Pixels @ 43,42 */ 16, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 09,43 */ 6, 0x91, 0x91, 0x94, 0x00, 
  /* RLE: 004 Pixels @ 15,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,43 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 004 Pixels @ 31,43 */ 4, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 006 Pixels @ 35,43 */ 6, 0xAF, 0xAF, 0xB3, 0x00, 
  /* RLE: 028 Pixels @ 41,43 */ 28, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,44 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 038 Pixels @ 31,44 */ 38, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 012 Pixels @ 19,45 */ 12, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 039 Pixels @ 31,45 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 011 Pixels @ 20,46 */ 11, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 039 Pixels @ 31,46 */ 39, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 010 Pixels @ 20,47 */ 10, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 041 Pixels @ 30,47 */ 41, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 008 Pixels @ 21,48 */ 8, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 044 Pixels @ 29,48 */ 44, 0x00, 0x00, 0x00, 0xFF, 
  /* RLE: 004 Pixels @ 23,49 */ 4, 0xA0, 0xA0, 0xA3, 0x00, 
  /* RLE: 023 Pixels @ 27,49 */ 23, 0x00, 0x00, 0x00, 0xFF, 
  0
};  // 983 bytes for 2500 pixels

GUI_CONST_STORAGE GUI_BITMAP bmThrobber_7_50x50 = {
  50, // xSize
  50, // ySize
  200, // BytesPerLine
  32, // BitsPerPixel
  (const unsigned char *)_acThrobber_7_50x50,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_RLE32
};

/*********************************************************************
*
*       _apbmThrobber
*/
static const GUI_BITMAP * _apbmThrobber[] = {
  &bmThrobber_0_50x50,
  &bmThrobber_1_50x50,
  &bmThrobber_2_50x50,
  &bmThrobber_3_50x50,
  &bmThrobber_4_50x50,
  &bmThrobber_5_50x50,
  &bmThrobber_6_50x50,
  &bmThrobber_7_50x50,
};

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
static void _cbAnim(WM_MESSAGE * pMsg) {
  static int       Index;
  static WM_HTIMER hTimer;

  switch(pMsg->MsgId) {
  case WM_CREATE:
    //
    // Create timer for drawing the frames
    //
    hTimer = WM_CreateTimer(pMsg->hWin, 0, MS_PER_FRAME, 0);
    break;
  case WM_PAINT:
    GUI_SetBkColor(GUI_WHITE);
    GUI_Clear();
    //
    // Draw current frame
    //
    GUI_DrawBitmap(*(_apbmThrobber + Index), 0, 0);
    break;
  case WM_TIMER:
    //
    // Update index when timer has run out
    //
    Index++;
    if (Index > (GUI_COUNTOF(_apbmThrobber) - 1)) {
      Index = 0;
    }
    //
    // Redraw window to show the new frame and restart the timer
    //
    WM_InvalidateWindow(pMsg->hWin);
    WM_RestartTimer(pMsg->Data.v, MS_PER_FRAME);
    break;
  default:
    WM_DefaultProc(pMsg);
  }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainTask(void) {
  GUI_Init();
  WM_MULTIBUF_Enable(1);
  WM_SetDesktopColor(GUI_WHITE);
  WM_CreateWindow(0, 0, bmThrobber_0_50x50.XSize, bmThrobber_0_50x50.YSize, WM_CF_SHOW, _cbAnim, 0);

  while(1) {
    GUI_Delay(50);
  }
}

/*************************** End of file ****************************/